# eolearn.core subpackage

The main subpackage which implements basic building blocks (EOPatch, EOTask and EOWorkflow) and commonly used functionalities.

For more information on the package content, visit [readthedocs](https://eo-learn.readthedocs.io/en/latest/eolearn.core.html).
